==> haskell-knob-0.2.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-knob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 knob
version:              0.2.1
visibility:           public
id:                   knob-0.2.1-6zBZoiWyVNK1mhdJ9ggVze
key:                  knob-0.2.1-6zBZoiWyVNK1mhdJ9ggVze
license:              MIT
maintainer:           Naïm Favier <n@monade.li>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/ncfavier/knob
synopsis:             Memory-backed handles
description:
    Create memory-backed '\''Handle'\''s, referencing virtual files. This is
    mostly useful for testing '\''Handle'\''-based APIs without having to
    interact with the filesystem.

    > import Data.ByteString (pack)
    > import Data.Knob
    > import System.IO
    >
    > main = do
    >     knob <- newKnob (pack [])
    >     h <- newFileHandle knob "test.txt" WriteMode
    >     hPutStrLn h "Hello world!"
    >     hClose h
    >     bytes <- Data.Knob.getContents knob
    >     putStrLn ("Wrote bytes: " ++ show bytes)

category:             System
abi:                  f8abff68906a068f71dfae0e660f8d3a
exposed:              True
exposed-modules:      Data.Knob
import-dirs:          /usr/lib/ghc-9.0.2/site-local/knob-0.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/knob-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-knob
hs-libraries:         HSknob-0.2.1-6zBZoiWyVNK1mhdJ9ggVze
depends:
    base-4.15.1.0 bytestring-0.10.12.1 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-knob/html/knob.haddock
haddock-html:         /usr/share/doc/haskell-knob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-knob-0.2.2-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-knob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 knob
version:              0.2.2
visibility:           public
id:                   knob-0.2.2-1ypFll9vgdD70mKIeOuazM
key:                  knob-0.2.2-1ypFll9vgdD70mKIeOuazM
license:              MIT
maintainer:           Naïm Favier <n@monade.li>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/ncfavier/knob
synopsis:             Memory-backed handles
description:
    Create memory-backed '\''Handle'\''s, referencing virtual files. This is
    mostly useful for testing '\''Handle'\''-based APIs without having to
    interact with the filesystem.

    > import Data.ByteString (pack)
    > import Data.Knob
    > import System.IO
    >
    > main = do
    >     knob <- newKnob (pack [])
    >     h <- newFileHandle knob "test.txt" WriteMode
    >     hPutStrLn h "Hello world!"
    >     hClose h
    >     bytes <- Data.Knob.getContents knob
    >     putStrLn ("Wrote bytes: " ++ show bytes)

category:             System
abi:                  212d8f85ef5b3421470d189925166700
exposed:              True
exposed-modules:      Data.Knob
import-dirs:          /usr/lib/ghc-9.0.2/site-local/knob-0.2.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/knob-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-knob
hs-libraries:         HSknob-0.2.2-1ypFll9vgdD70mKIeOuazM
depends:
    base-4.15.1.0 bytestring-0.10.12.1 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-knob/html/knob.haddock
haddock-html:         /usr/share/doc/haskell-knob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
